<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtrar:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../../forms/fontdialog.ui" line="14"/>
        <location filename="../../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Selecione o tipo de fonte</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Fonte:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Pré-visualização</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="79"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation type="vanished">Renomear sessão</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="171"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Pressione &quot;%1&quot; para ver o terminal.</translation>
    </message>
    <message>
        <source>&amp;Clear Current Tab</source>
        <translation type="vanished">&amp;Limpar aba atual</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="218"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Próxima aba</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="221"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Aba anterior</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="224"/>
        <source>Move Tab &amp;Left</source>
        <translation>Mover aba para a esquerda</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="227"/>
        <source>Move Tab &amp;Right</source>
        <translation>Mover aba para a direta</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="232"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Dividir terminal &amp;horizontalmente</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="235"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Dividir terminal &amp;verticalmente</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="240"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Recolher subterminal</translation>
    </message>
    <message>
        <source>N&amp;ext Subterminal</source>
        <translation type="vanished">Próximo subterminal</translation>
    </message>
    <message>
        <source>P&amp;revious Subterminal</source>
        <translation type="vanished">Subterminal anterior</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="211"/>
        <source>&amp;Clear Active Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <source>&amp;Top Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="246"/>
        <source>&amp;Bottom Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="249"/>
        <source>L&amp;eft Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="252"/>
        <source>R&amp;ight Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="259"/>
        <source>Copy &amp;Selection</source>
        <translation>Copiar &amp;seleção</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Paste Clip&amp;board</source>
        <translation>Colar da área de trans&amp;ferência</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="265"/>
        <source>Paste S&amp;election</source>
        <translation>Colar &amp;seleção</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="268"/>
        <source>Zoom &amp;in</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="271"/>
        <source>Zoom &amp;out</source>
        <translation>Reduzir</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="274"/>
        <source>Zoom rese&amp;t</source>
        <translation>Tamanho normal</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="279"/>
        <source>&amp;Find...</source>
        <translation>&amp;Localizar...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="287"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Salvar sessão</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="293"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Carregar sessão</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="300"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Esconder Menu</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="305"/>
        <source>Rename session</source>
        <translation type="unfinished">Renomear sessão</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="313"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nova aba</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="317"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nova aba &amp;predefinida</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="318"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminal</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="320"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;terminais horizontais</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="322"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;terminais verticais</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="324"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 terminai&amp;s</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="330"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Fechar aba</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="333"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nova janela</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="338"/>
        <source>&amp;Preferences...</source>
        <translation type="unfinished">&amp;Preferências...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="342"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Sair</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="348"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Ocultar bordas da janela</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="359"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Mostrar barra de abas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="367"/>
        <source>Fullscreen</source>
        <translation>&amp;Tela cheia</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="373"/>
        <source>Toggle Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="381"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Baixo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="382"/>
        <source>&amp;Top</source>
        <translation>&amp;Topo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="383"/>
        <location filename="../../mainwindow.cpp" line="419"/>
        <source>&amp;Right</source>
        <translation>&amp;Direta</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="384"/>
        <location filename="../../mainwindow.cpp" line="420"/>
        <source>&amp;Left</source>
        <translation>&amp;Esquerda</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="402"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Posição da barra de abas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="418"/>
        <source>&amp;None</source>
        <translation>&amp;Sem barra de rolagem</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="436"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Po&amp;sição da barra de rolagem</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="449"/>
        <source>&amp;BlockCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="450"/>
        <source>&amp;UnderlineCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="451"/>
        <source>&amp;IBeamCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="468"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="558"/>
        <source>Exit QTerminal</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="560"/>
        <source>Do not ask again</source>
        <translation>Não perguntar novamente</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="568"/>
        <source>Are you sure you want to exit?</source>
        <translation>Tem certeza que deseja sair?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="598"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>Um emulador de terminal leve e multiplataforma</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Preferências do terminal</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="52"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="57"/>
        <location filename="../../forms/propertiesdialog.ui" line="457"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="62"/>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="67"/>
        <source>Dropdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="72"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="100"/>
        <source>Color scheme</source>
        <translation>Esquema de cores</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="296"/>
        <source>Widget style</source>
        <translation>Estilo do widget</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="110"/>
        <source>Scrollbar position</source>
        <translation>Posição da barra de rolagem</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="267"/>
        <source>Tabs position</source>
        <translation>Posição da barra de abas</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="319"/>
        <source>Show the menu bar</source>
        <translation>Mostrar barra de menu</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="90"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Esconder barra de abas quando houver apenas uma</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="136"/>
        <source>Show a border around the current terminal</source>
        <translation>Mostrar borda ao redor do terminal</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="153"/>
        <source>Application transparency</source>
        <translation>Transparência de aplicativo</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="143"/>
        <source>Terminal transparency</source>
        <translation>Transparência do terminal</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="187"/>
        <location filename="../../forms/propertiesdialog.ui" line="280"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="120"/>
        <source>Start with preset:</source>
        <translation>Iniciar terminal com predefinição:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="164"/>
        <source>None (single terminal)</source>
        <translation>Não (um terminal)</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="169"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminais horizontais</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="174"/>
        <source>2 terminals vertically</source>
        <translation>2 terminais verticais</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="179"/>
        <source>4 terminals</source>
        <translation>4 terminais</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="218"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="254"/>
        <source>&amp;Change...</source>
        <translation>&amp;Alterar...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="326"/>
        <source>Keyboard cursor shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="336"/>
        <source>Change window title based on current terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="343"/>
        <source>Change window icon based on current terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="350"/>
        <source>Enable bi-directional text support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="357"/>
        <source>Background image:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="369"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="378"/>
        <source>Show terminal size on resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="385"/>
        <source>Limit tab width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="395"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="405"/>
        <source>Show close button on each tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="432"/>
        <source>Emulation</source>
        <translation>Emulação</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="441"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="463"/>
        <source>Action after paste</source>
        <translation>Ação após colar</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="473"/>
        <source>Confirm multiline paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="480"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="513"/>
        <source>Open new terminals in current working directory</source>
        <translation>Abrir novos terminais no diretório de trabalho atual</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="520"/>
        <source>Save Size when closing</source>
        <translation>Salvar tamanho ao fechar</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="527"/>
        <source>Save Position when closing</source>
        <translation>Salvar posição ao fechar</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="534"/>
        <source>Ask for confirmation when closing</source>
        <translation>Pedir confirmação ao fechar</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="544"/>
        <source>Unlimited history</source>
        <translation>Histórico ilimitado</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="551"/>
        <source>History size (in lines)</source>
        <translation>Tamanho do histórico (linhas)</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="558"/>
        <source>Default $TERM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="572"/>
        <source>xterm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="577"/>
        <source>xterm-256color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="614"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="619"/>
        <source>Key</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="631"/>
        <source>Show on start</source>
        <translation>Mostrar no inicio</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="638"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="649"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="659"/>
        <location filename="../../forms/propertiesdialog.ui" line="676"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="666"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="690"/>
        <source>Shortcut:</source>
        <translation>Atalho:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="722"/>
        <source>Edit bookmark file contents</source>
        <translation>Editar conteúdo do arquivo de marcadores</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="744"/>
        <source>Enable bookmarks</source>
        <translation>Habilitar marcadores</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="753"/>
        <source>Bookmark file</source>
        <translation>Arquivo de marcadores</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="766"/>
        <source>Find...</source>
        <translation>Localizar...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="775"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Você pode especificar a localização do arquivo de marcadores. Isso permite o compartilhamento de marcadores através do Own Cloud, Dropbox e mais serviços.</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <source>No scrollbar</source>
        <translation>Sem barra de rolagem</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Top</source>
        <translation>Topo</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Bottom</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>BlockCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>UnderlineCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>IBeamCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>No move</source>
        <translation>Não mover</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move start</source>
        <translation>Mover para o inicio</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move end</source>
        <translation>Mover para o fim</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="129"/>
        <location filename="../../propertiesdialog.cpp" line="199"/>
        <source>System Default</source>
        <translation>Padrão do sistema</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="282"/>
        <source>Choose a background image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="283"/>
        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="348"/>
        <source>Open or create bookmarks file</source>
        <translation>Abrir ou criar arquivo de marcadores</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../../termwidget.cpp" line="237"/>
        <source>Show Details...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="110"/>
        <source>Local Bookmarks</source>
        <translation>Marcadores locais</translation>
    </message>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="168"/>
        <source>Synchronized Bookmarks</source>
        <translation>Marcadores sincronizados</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../../tabwidget.cpp" line="73"/>
        <location filename="../../tabwidget.cpp" line="219"/>
        <source>Shell No. %1</source>
        <translation>Console n.º %1</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="187"/>
        <source>Tab name</source>
        <translation>Nome da aba</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="188"/>
        <source>New tab name:</source>
        <translation>Novo nome da aba:</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="208"/>
        <source>Select new tab title color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="229"/>
        <source>Close session</source>
        <translation>Fechar sessão</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="231"/>
        <source>Change title color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename session</source>
        <translation type="vanished">Renomear sessão</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../../termwidgetholder.cpp" line="78"/>
        <source>Load Session</source>
        <translation>Carregar sessão</translation>
    </message>
    <message>
        <location filename="../../termwidgetholder.cpp" line="79"/>
        <source>List of saved sessions:</source>
        <translation>Lista de sessões salvas:</translation>
    </message>
</context>
<context>
    <name>TermWidgetImpl</name>
    <message>
        <location filename="../../termwidget.cpp" line="229"/>
        <source>Paste multiline text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../termwidget.cpp" line="230"/>
        <source>Are you sure you want to paste this text?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Janela Principal</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Ações</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Sobre...</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Sobre Qt...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation type="vanished">&amp;Preferências...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="vanished">&amp;Sair</translation>
    </message>
</context>
</TS>
